import dotenv from 'dotenv';
import { startBot } from './bot/bot';
import { startServer } from './server/server';

// Load environment variables
dotenv.config();

// Get port from environment or default to 3000
const PORT = process.env.PORT ? parseInt(process.env.PORT) : 3000;

// Start the bot and server
async function main() {
  try {
    console.log('Starting bot...');
    await startBot();
    console.log('Bot started successfully');
    
    console.log('Starting server...');
    startServer(PORT);
    console.log(`Server running on port ${PORT}`);
  } catch (error) {
    console.error('Error starting application:', error);
    process.exit(1);
  }
}

// Handle process termination
process.on('SIGINT', () => {
  console.log('Shutting down gracefully...');
  process.exit(0);
});

process.on('SIGTERM', () => {
  console.log('Shutting down gracefully...');
  process.exit(0);
});

main();
